@@ -1,17 +1,24 @@
-package Clustericious::Command::status;
+=head1 NAME
 
-use strict;
-use warnings;
+Clustericious::Command::status
+
+=head1 DESCRIPTION
+
+Report the status of a running clustericious daemon, based on its start_mode.
+
+=cut
+
+package Clustericious::Command::status;
 use Clustericious::Log;
 use Mojo::UserAgent;
+
 use Clustericious::App;
 use Clustericious::Config;
 use File::Basename qw/dirname/;
-use base 'Clustericious::Command';
-
-# ABSTRACT: Clustericious command to report status of Clustericious application
-our $VERSION = '0.9940_04'; # VERSION
+use base 'Mojolicious::Command';
 
+use strict;
+use warnings;
 
 __PACKAGE__->attr(description => <<'');
 Report the status of a daemon.
@@ -57,7 +64,6 @@ sub _check_database {
 
 sub run {
     my $self = shift;
-    exit 2 unless $self->app->sanity_check;
     my @args = @_ ? @_ : @ARGV;
     my $app  = $ENV{MOJO_APP};
     my $conf = Clustericious::Config->new($app);
@@ -103,50 +109,3 @@ sub run {
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Clustericious::Command::status - Clustericious command to report status of Clustericious application
-
-=head1 VERSION
-
-version 0.9940_04
-
-=head1 SYNOPSIS
-
- % yourapp status
-
-=head1 DESCRIPTION
-
-Report the status of a running clustericious daemon, based on its start_mode.
-
-=head1 SUPER CLASS
-
-L<Clustericious::Command>
-
-=head1 SEE ALSO
-
-L<Clustericious>
-
-=head1 AUTHOR
-
-original author: Brian Duggan
-
-current maintainer: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Curt Tilmes
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by NASA GSFC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
